@@ -17,22 +17,18 @@ from sparrow.llm.openaiclient import OpenAIClient
 
 class StepStatus(Enum):
     """步骤执行状态枚举"""
-    PENDING = "pending"      # 等待执行
     RUNNING = "running"      # 正在执行
     COMPLETED = "completed"  # 执行完成
     FAILED = "failed"        # 执行失败
     TIMEOUT = "timeout"      # 执行超时
-    CANCELLED = "cancelled"  # 执行取消
 
 
 class ChainStatus(Enum):
     """链条执行状态枚举"""
-    PENDING = "pending"      # 等待执行
     RUNNING = "running"      # 正在执行
     COMPLETED = "completed"  # 执行完成
     FAILED = "failed"        # 执行失败
     TIMEOUT = "timeout"      # 执行超时
-    CANCELLED = "cancelled"  # 执行取消
 
 
 @dataclass
@@ -71,16 +67,14 @@ class StepExecutionInfo:
         execution_time: 执行时间
         retry_count: 重试次数
         error: 错误信息
-        memory_usage: 内存使用量（可选）
     """
     step_name: str
-    status: StepStatus = StepStatus.PENDING
+    status: StepStatus = StepStatus.RUNNING
     start_time: Optional[float] = None
     end_time: Optional[float] = None
     execution_time: Optional[float] = None
     retry_count: int = 0
     error: Optional[str] = None
-    memory_usage: Optional[float] = None
 
 
 @dataclass
@@ -95,17 +89,15 @@ class ChainExecutionInfo:
         end_time: 结束时间
         total_execution_time: 总执行时间
         steps_info: 各步骤执行信息
-        total_steps: 总步骤数
         completed_steps: 已完成步骤数
         error: 错误信息
     """
     chain_id: str
-    status: ChainStatus = ChainStatus.PENDING
+    status: ChainStatus = ChainStatus.RUNNING
     start_time: Optional[float] = None
     end_time: Optional[float] = None
     total_execution_time: Optional[float] = None
     steps_info: List[StepExecutionInfo] = field(default_factory=list)
-    total_steps: int = 0
     completed_steps: int = 0
     error: Optional[str] = None
 
@@ -169,17 +161,16 @@ class DefaultChainMonitor(ChainMonitor):
             status_msg = f"链条 {chain_info.chain_id} 执行结束 - 状态: {chain_info.status.value}"
             if chain_info.total_execution_time:
                 status_msg += f", 总耗时: {chain_info.total_execution_time:.2f}秒"
-            status_msg += f", 完成步骤: {chain_info.completed_steps}/{chain_info.total_steps}"
+            status_msg += f", 完成步骤: {chain_info.completed_steps}"
             self._log("INFO", status_msg)
     
     async def on_step_start(self, step_info: StepExecutionInfo, chain_info: ChainExecutionInfo) -> None:
         if self.config.enable_monitoring:
-            progress = f"({chain_info.completed_steps + 1}/{chain_info.total_steps})"
+            progress = f"({chain_info.completed_steps + 1})"
             self._log("DEBUG", f"步骤 {step_info.step_name} 开始执行 {progress}")
             
             if self.config.enable_progress:
-                progress_percent = ((chain_info.completed_steps + 1) / chain_info.total_steps) * 100
-                print(f"执行进度: {progress_percent:.1f}% - {step_info.step_name}")
+                print(f"执行进度: 步骤 {chain_info.completed_steps + 1} - {step_info.step_name}")
     
     async def on_step_end(self, step_info: StepExecutionInfo, chain_info: ChainExecutionInfo) -> None:
         if self.config.enable_monitoring:
@@ -204,15 +195,6 @@ class ExecutionController:
     
     def __init__(self, config: ExecutionConfig):
         self.config = config
-        self._cancelled = False
-    
-    def cancel(self) -> None:
-        """取消执行"""
-        self._cancelled = True
-    
-    def is_cancelled(self) -> bool:
-        """检查是否已取消"""
-        return self._cancelled
     
     async def check_timeout(self, start_time: float, timeout: Optional[float]) -> bool:
         """检查是否超时"""
@@ -452,10 +434,6 @@ class ChainOfThoughtClient:
         last_error = None
         
         for attempt in range(self.execution_config.max_retries + 1):
-            if controller.is_cancelled():
-                step_info.status = StepStatus.CANCELLED
-                return None
-            
             step_info.retry_count = attempt
             
             try:
@@ -579,9 +557,6 @@ class ChainOfThoughtClient:
         
         controller = ExecutionController(self.execution_config)
         
-        # 估算总步骤数（简单预估）
-        chain_info.total_steps = len(self.steps)  # 这是一个保守估计
-        
         try:
             await self.monitor.on_chain_start(chain_info)
             
@@ -596,11 +571,6 @@ class ChainOfThoughtClient:
                         await self.monitor.on_timeout("chain", chain_info)
                         break
                 
-                # 检查取消状态
-                if controller.is_cancelled():
-                    chain_info.status = ChainStatus.CANCELLED
-                    break
-                
                 if current_step_name not in self.steps:
                     raise ValueError(f"执行过程中发现未注册的步骤 '{current_step_name}'。")
 
